#include "intuition.h"

struct NewScreen NewScreen = {
    0,0,        /* leftedge ,topedge */
    640,400,    /* width, height */
    4,          /* depth, 4=16 colors */
    0,1,        /* detail color, blockpen color */
    HIRES|INTERLACE,      /* viewmode */
    CUSTOMSCREEN, /* screen type */
    NULL,       /* font */
    (UBYTE*)"Graphics", /* title */
    NULL,       /* gadgets */
    NULL,       /* bitmap */
};

struct NewWindow NewWindow = {
    0,0,
    640,400,
    0,1,
    MENUPICK | CLOSEWINDOW,
    WINDOWCLOSE | SMART_REFRESH | ACTIVATE,
    NULL,NULL,(UBYTE*)"Graphics 1.0",
    NULL,NULL,50,25,640,400,CUSTOMSCREEN,
};

struct IntuitionBase *IntuitionBase;
struct GfxBase *GfxBase;
struct Screen *Screen;
struct Window *Window;
struct RastPort *RastPort;
extern struct Menu Project_menu;

void close_all(void)
{
    if (Window) CloseWindow(Window);
    if (Screen) CloseScreen(Screen);
    if (GfxBase) CloseLibrary(GfxBase);
    if (IntuitionBase) CloseLibrary(IntuitionBase);
}

void init_libs(void)
{
    IntuitionBase = (struct IntuitionBase *)OpenLibrary("intuition.library",0L);
    if (IntuitionBase == NULL) {
        fprintf(stderr,"error opening intuition.library\n");
        exit(25);
    }
    GfxBase = (struct GfxBase *) OpenLibrary("graphics.library",0L);
    if (GfxBase == NULL) {
        fprintf(stderr,"error opening graphics.library\n");
        close_all();
        exit(25);
    }
}

void init_screen(void)
{
    Screen = (struct Screen *)OpenScreen(&NewScreen);
    if (Screen == NULL) {
        fprintf(stderr,"error opening screen\n");
        close_all();
        exit(25);
    }
    RastPort = &Screen->RastPort;
}

void init_window(void)
{
    NewWindow.Screen = Screen;
    Window = OpenWindow(&NewWindow);
    if (Window == NULL) {
        fprintf(stderr,"error opening window\n");
        close_all();
        exit(25);
    }
    SetMenuStrip(Window, &Project_menu);
}

/* This function returns:
    0 when the CLOSE gadget is hit,
    1 when a menu item is picked
    It can be easily extended to return gadgets, mouse xy, etc
*/

long handle_user(long *menu,long *item,long *sub)
{
    long rc,class,code;
    struct IntuiMessage *message;

    Wait(1<<Window->UserPort->mp_SigBit);
    message = (struct IntuiMessage *)GetMsg(Window->UserPort);
    class = message->Class;
    code = message->Code;
    ReplyMsg((struct Message *)message);
    switch (class) {
        case CLOSEWINDOW: rc=0;break;
        case MENUPICK: {
            *menu = MENUNUM(code);
            *item = ITEMNUM(code);
            *sub = SUBNUM(code);
            rc = 1;
        }
    }
    return rc;
}
